==> peaceful-progression-1.1.0-sources.jar: xen42/peacefulitems/item/BrushDispenserBehavior.java <==
package xen42.peacefulitems.item;

import java.util.List;
import net.minecraft.class_1301;
import net.minecraft.class_1440;
import net.minecraft.class_1799;
import net.minecraft.class_2315;
import net.minecraft.class_2338;
import net.minecraft.class_2342;
import net.minecraft.class_238;
import net.minecraft.class_2969;
import net.minecraft.class_3218;
import net.minecraft.class_9069;

public class BrushDispenserBehavior extends class_2969 {
    @Override
    protected class_1799 method_10135(class_2342 pointer, class_1799 stack) {
        class_3218 serverWorld = pointer.comp_1967();
        class_2338 blockPos = pointer.comp_1968().method_10093(pointer.comp_1969().method_11654(class_2315.field_10918));
        List<class_9069> armadilloList = serverWorld.method_8390(class_9069.class, new class_238(blockPos), class_1301.field_6155);
        List<class_1440> pandaList = serverWorld.method_8390(class_1440.class, new class_238(blockPos), class_1301.field_6155);
        if (armadilloList.isEmpty() && pandaList.isEmpty()) {
            this.method_27955(false);
            return stack;
        } else {
            for (class_9069 armadilloEntity : armadilloList) {
                if (armadilloEntity.method_55716()) {
                    this.method_27955(true);
                    stack.method_7970(16, armadilloEntity, null);
                    return stack;
                }
            }
            for (class_1440 pandaEntity : pandaList) {
                if (!pandaEntity.method_6545()) {
                    pandaEntity.method_6546(true);
                    this.method_27955(true);
                    stack.method_7970(1, pandaEntity, null);
                    return stack;
                }
            }

            this.method_27955(false);
            return stack;
        }
    }
}

==> peaceful-progression-1.1.1-sources.jar: xen42/peacefulitems/item/BrushDispenserBehavior.java <==
package xen42.peacefulitems.item;

import java.util.List;
import net.minecraft.class_1301;
import net.minecraft.class_1440;
import net.minecraft.class_1799;
import net.minecraft.class_2315;
import net.minecraft.class_2338;
import net.minecraft.class_2342;
import net.minecraft.class_238;
import net.minecraft.class_2969;
import net.minecraft.class_3218;
import net.minecraft.class_9069;

public class BrushDispenserBehavior extends class_2969 {
    @Override
    protected class_1799 method_10135(class_2342 pointer, class_1799 stack) {
        class_3218 serverWorld = pointer.comp_1967();
        class_2338 blockPos = pointer.comp_1968().method_10093(pointer.comp_1969().method_11654(class_2315.field_10918));
        List<class_9069> armadilloList = serverWorld.method_8390(class_9069.class, new class_238(blockPos), class_1301.field_6155);
        List<class_1440> pandaList = serverWorld.method_8390(class_1440.class, new class_238(blockPos), class_1301.field_6155);
        if (armadilloList.isEmpty() && pandaList.isEmpty()) {
            this.method_27955(false);
            return stack;
        } else {
            for (class_9069 armadilloEntity : armadilloList) {
                if (armadilloEntity.method_55716(null, stack)) {
                    this.method_27955(true);
                    stack.method_7956(16, serverWorld, null, item -> {});
                    return stack;
                }
            }
            for (class_1440 pandaEntity : pandaList) {
                if (!pandaEntity.method_6545()) {
                    pandaEntity.method_6546(true);
                    this.method_27955(true);
                    stack.method_7956(1, serverWorld, null, item -> {});
                    return stack;
                }
            }

            this.method_27955(false);
            return stack;
        }
    }
}
